@@ -51,7 +51,7 @@
 static void missing_attr_msg(const char *par, const char *item)
 {
        parsemsg( LOG_WARNING, par, 
-          "attribute %s expects at least 1 value and none were given.",
+          "attribute %s expects at least 1 value and none was given.",
 	   item );
 }
 
@@ -934,6 +934,11 @@ status_e log_type_parser( pset_h values,
       missing_attr_msg(func, "log_type");
       return( FAILED );
    }
+
+   if ( LOG_GET_TYPE( lp ) != L_NONE) {
+      parsemsg( LOG_ERR, func, "Cannot set more than one log_type attribute");
+      return( FAILED );
+   }
    
    type = (char *) pset_pointer( values, 0 ) ;
 
